@@ -13,10 +13,20 @@ import functools
 import imgkit
 
 
-class Address:
-    """
+def build_xml(user, password, con):
+    return f"""<?xml version="1.0" encoding="UTF-8"?>
+    <trackingrequest>
+    <user>{user}</user>
+    <password>{password}</password>
+    <trackingnumbers>
+    <trackingnumber>{con}</trackingnumber>
+    </trackingnumbers>
+    </trackingrequest>"""
 
-    """
+
+
+
+class Address:
 
     def __init__(self, *args, **kwargs):
         """
@@ -109,6 +119,12 @@ class Parcel(Address):
         self.pcs = kwargs.get("pcs", 1)
         super().__init__(*args, **kwargs)
 
+class Tracking:
+    def __init__(self, consignment):
+        """
+
+        """
+
 
 class Delivery:
     """
@@ -226,7 +242,8 @@ class Delivery:
                    'margin-bottom': f'{margins[2]}in',
                    'margin-left': f'{margins[3]}in',
                    '--quiet': '',
-                   'zoom': zoom,
+                   '--zoom': str(zoom),
+                   'zoom': str(zoom),
                    }
 
         css = """<style>
@@ -300,7 +317,7 @@ class Delivery:
             filename = secrets.token_urlsafe(10)
 
         #get the final path
-        final_path = out_path + "/" if out_path[-1] != "/" else "" + filename
+        final_path = (out_path + filename).replace("//","/")
 
         #get list for to reutrn
         filenames = []
@@ -402,8 +419,11 @@ class DPD:
 
         # create dictionary for available services
         services = {}
-        for i in req.json()["data"]:
-            services[i["network"]["networkDescription"].title()] = i["network"]["networkCode"]
+        if req.json()["data"]:
+            for i in req.json()["data"]:
+                services[i["network"]["networkDescription"].title()] = i["network"]["networkCode"]
+        else:
+            raise Exception("Issue with parcel, no services found, possibly postcode not valid")
 
         return services
 
